@@ -311,7 +311,9 @@ BLACKLISTED_PROJECTS = [
     "c",
     "wait",
     "dashboard",
-    "docs/*, tickets/*, requests/*",
+    "docs/*",
+    "tickets/*",
+    "requests/*",
 ]
 
 # List of prefix allowed in project names
@@ -351,6 +353,8 @@ ACLS = {
     ),
     "update_watch_status": "Update the watch status on a project",
     "pull_request_rebase": "Rebase a pull-request",
+    "tag_project": "Allows adding git tags to a project",
+    "commit": "Commit to a git repository via http(s)",
 }
 
 # List of ACLs which a regular user is allowed to associate to an API token
@@ -369,6 +373,7 @@ CROSS_PROJECT_ACLS = [
     "modify_project",
     "update_watch_status",
     "pull_request_create",
+    "commit",
 ]
 
 # ACLs with which admins are allowed to create project-less API tokens
@@ -383,6 +388,7 @@ ADMIN_API_ACLS = [
     "generate_acls_project",
     "commit_flag",
     "create_branch",
+    "tag_project",
 ]
 
 # List of the type of CI service supported by this pagure instance
@@ -438,6 +444,7 @@ STOMP_CERT_FILE = None
 STOMP_CREDS_PASSWORD = None
 STOMP_HIERARCHY = None
 
+
 LOGGING = {
     "version": 1,
     "disable_existing_loggers": False,
@@ -450,7 +457,11 @@ LOGGING = {
     "filters": {"myfilter": {"()": ContextInjector}},
     "handlers": {
         "console": {
-            "level": "INFO",
+            "formatter": "standard",
+            "class": "logging.StreamHandler",
+            "stream": "ext://sys.stdout",
+        },
+        "auth_handler": {
             "formatter": "standard",
             "class": "logging.StreamHandler",
             "stream": "ext://sys.stdout",
@@ -475,6 +486,11 @@ LOGGING = {
             "level": "DEBUG",
             "propagate": True,
         },
+        "pagure_auth": {
+            "handlers": ["auth_handler"],
+            "level": "DEBUG",
+            "propagate": False,
+        },
         "flask": {
             "handlers": ["console"],
             "level": "INFO",
