@@ -16,10 +16,13 @@ import logging
 import string
 import time
 import os
+import warnings
 
 import flask
 import pygit2
 
+from whitenoise import WhiteNoise
+
 import pagure.doc_utils
 import pagure.exceptions
 import pagure.forms
@@ -132,7 +135,30 @@ def create_app(config=None):
     # Import 3rd party blueprints
     plugin_config = flask.config.Config("")
     if "PAGURE_PLUGIN" in os.environ:
+        # Warn the user about deprecated variable (defaults to stderr)
+        warnings.warn(
+            "The environment variable PAGURE_PLUGIN is deprecated and will be "
+            "removed in future releases of Pagure. Please replace it with "
+            "PAGURE_PLUGINS_CONFIG instead.",
+            FutureWarning,
+        )
+
+        # Log usage of deprecated variable
+        logger.warning(
+            "Using deprecated variable PAGURE_PLUGIN. "
+            "You should use PAGURE_PLUGINS_CONFIG instead."
+        )
+
         plugin_config.from_envvar("PAGURE_PLUGIN")
+
+    elif "PAGURE_PLUGINS_CONFIG" in os.environ:
+        plugin_config.from_envvar("PAGURE_PLUGINS_CONFIG")
+
+    elif "PAGURE_PLUGINS_CONFIG" in app.config:
+        # If the os.environ["PAGURE_PLUGINS_CONFIG"] is not set, we try to load
+        # it from the pagure config file.
+        plugin_config.from_pyfile(app.config.get("PAGURE_PLUGINS_CONFIG"))
+
     for blueprint in plugin_config.get("PLUGINS") or []:
         logger.info("Loading blueprint: %s", blueprint.name)
         app.register_blueprint(blueprint)
@@ -164,6 +190,11 @@ def create_app(config=None):
     app.jinja_loader = jinja2.ChoiceLoader(templ_loaders)
     app.register_blueprint(themeblueprint)
 
+    # Setup WhiteNoise for serving static files
+    app.wsgi_app = WhiteNoise(
+        app.wsgi_app, root=os.path.join(here, "static"), prefix="/static"
+    )
+
     app.before_request(set_request)
     app.after_request(after_request)
     app.teardown_request(end_request)
@@ -364,6 +395,11 @@ def set_request():
         flask.g.repo_obj = pygit2.Repository(flask.g.reponame)
         flask.g.repo_admin = pagure.utils.is_repo_admin(flask.g.repo)
         flask.g.repo_committer = pagure.utils.is_repo_committer(flask.g.repo)
+        if flask.g.authenticated and not flask.g.repo_committer:
+            flask.g.repo_committer = flask.g.fas_user.username in [
+                u.user.username for u in flask.g.repo.collaborators
+            ]
+
         flask.g.repo_user = pagure.utils.is_repo_user(flask.g.repo)
         flask.g.branches = sorted(flask.g.repo_obj.listall_branches())
 
@@ -498,6 +534,9 @@ def end_request(exception=None):
 
 def after_request(response):
     """ After request callback, adjust the headers returned """
+    if not hasattr(flask.g, "nonce"):
+        return response
+
     csp_headers = pagure_config["CSP_HEADERS"]
     try:
         style_csp = "nonce-" + flask.g.nonce
