@@ -36,10 +36,11 @@ from pagure.utils import urlpattern, is_admin
 STRICT_REGEX = "^[a-zA-Z0-9-_]+$"
 # This regex is used when creating tags, there we do not want to allow ','
 # as otherwise it breaks the UI.
-TAGS_REGEX = "^[a-zA-Z0-9-_ .:]+$"
+TAGS_REGEX = "^[a-zA-Z0-9][a-zA-Z0-9-_ .:]+$"
+TAGS_REGEX_RE = re.compile(TAGS_REGEX)
 # In the issue page tags are sent as a comma-separated list, so in order to
 # allow having multiple tags in an issue, we need to allow ',' in them.
-TAGS_REGEX_MULTI = "^[a-zA-Z0-9-_, .:]+$"
+TAGS_REGEX_MULTI = "^[a-zA-Z0-9][a-zA-Z0-9-_, .:]+$"
 FALSE_VALUES = ("false", "", False, "False", 0, "0")
 
 WTF_VERSION = tuple()
@@ -159,6 +160,10 @@ class ProjectFormSimplified(PagureForm):
     private = wtforms.BooleanField(
         "Private", [wtforms.validators.Optional()], false_values=FALSE_VALUES
     )
+    mirrored_from = wtforms.StringField(
+        "Mirrored from",
+        [wtforms.validators.optional(), wtforms.validators.Length(max=255)],
+    )
 
 
 class ProjectForm(ProjectFormSimplified):
@@ -201,6 +206,9 @@ class ProjectForm(ProjectFormSimplified):
         coerce=convert_value,
         default=pagure_config["REPOSPANNER_NEW_REPO"],
     )
+    default_branch = wtforms.StringField(
+        "Default branch", [wtforms.validators.optional()],
+    )
 
     def __init__(self, *args, **kwargs):
         """ Calls the default constructor with the normal argument but
@@ -366,6 +374,26 @@ class AddIssueTagForm(DeleteIssueTagForm):
     )
 
 
+class ApiAddIssueTagForm(PagureForm):
+    """ Form to add a tag to a project from the API endpoint """
+
+    tag = wtforms.StringField(
+        "Tag",
+        [
+            wtforms.validators.DataRequired(),
+            wtforms.validators.Regexp(TAGS_REGEX, flags=re.IGNORECASE),
+            wtforms.validators.Length(max=255),
+        ],
+    )
+
+    tag_description = wtforms.StringField(
+        "Tag Description", [wtforms.validators.Optional()]
+    )
+    tag_color = wtforms.StringField(
+        "Tag Color", [wtforms.validators.DataRequired()]
+    )
+
+
 class StatusForm(PagureForm):
     """ Form to add/change the status of an issue. """
 
@@ -422,6 +450,11 @@ class NewTokenForm(PagureForm):
     description = wtforms.StringField(
         "description", [wtforms.validators.Optional()]
     )
+    expiration_date = wtforms.DateField(
+        "expiration date",
+        [wtforms.validators.DataRequired()],
+        default=datetime.date.today() + datetime.timedelta(days=(30 * 6)),
+    )
     acls = wtforms.SelectMultipleField(
         "ACLs", [wtforms.validators.DataRequired()], choices=[]
     )
@@ -599,6 +632,10 @@ class AddUserForm(PagureForm):
         'Access Level <span class="error">*</span>',
         [wtforms.validators.DataRequired()],
     )
+    branches = wtforms.StringField(
+        'Git branches <span class="error">*</span>',
+        [wtforms.validators.Optional()],
+    )
 
 
 class AddUserToGroupForm(PagureForm):
@@ -633,6 +670,10 @@ class AddGroupForm(PagureForm):
         'Access Level <span class="error">*</span>',
         [wtforms.validators.DataRequired()],
     )
+    branches = wtforms.StringField(
+        'Git branches <span class="error">*</span>',
+        [wtforms.validators.Optional()],
+    )
 
 
 class ConfirmationForm(PagureForm):
@@ -906,3 +947,23 @@ class TriggerCIPRForm(PagureForm):
     comment = wtforms.SelectField(
         "comment", [wtforms.validators.Required()], choices=[]
     )
+
+
+class AddGitTagForm(PagureForm):
+    """ Form to create a new git tag. """
+
+    tagname = wtforms.StringField(
+        'Name of the tag<span class="error">*</span>',
+        [wtforms.validators.DataRequired()],
+    )
+    commit_hash = wtforms.StringField(
+        "Hash of the commit to tag", [wtforms.validators.DataRequired()]
+    )
+    message = wtforms.TextAreaField(
+        "Annotation message", [wtforms.validators.Optional()]
+    )
+    force = wtforms.BooleanField(
+        "Force the creation of the git tag",
+        [wtforms.validators.optional()],
+        false_values=FALSE_VALUES,
+    )
