@@ -180,6 +180,8 @@ class BaseHook(object):
                 # Install the main hook file
                 target = os.path.join(hookfolder, hooktype)
                 if not os.path.exists(target):
+                    if os.path.islink(target):
+                        os.unlink(target)
                     os.symlink(os.path.join(hook_files, "hookrunner"), target)
 
     @classmethod
@@ -320,11 +322,7 @@ def run_project_hooks(
     # First we run dynamic ACLs
     authbackend = get_git_auth_helper()
 
-    if (
-        is_internal
-        and username == "pagure"
-        and repotype in ("tickets", "requests")
-    ):
+    if is_internal and username == "pagure":
         if debug:
             print("This is an internal push, dynamic ACL is pre-approved")
     elif not authbackend.is_dynamic:
