@@ -18,7 +18,7 @@ import subprocess
 import tempfile
 from io import open
 
-import werkzeug
+import werkzeug.utils
 from six import with_metaclass
 from six.moves import dbm_gnu
 
@@ -27,7 +27,7 @@ import pagure.lib.model_base
 import pagure.lib.query
 from pagure.config import config as pagure_config
 from pagure.lib import model
-from pagure.utils import is_repo_committer, lookup_deploykey
+from pagure.utils import is_repo_collaborator, lookup_deploykey
 
 
 # logging.config.dictConfig(pagure_config.get('LOGGING') or {'version': 1})
@@ -74,6 +74,7 @@ def get_git_auth_helper(backend=None):
             "gitolite2": Gitolite2Auth,
             "gitolite3": Gitolite3Auth,
             "pagure": PagureGitAuth,
+            "pagure_authorized_keys": PagureGitAuth,
         }[backend]
     else:
         cls = classes[backend].load()
@@ -270,7 +271,7 @@ class Gitolite2Auth(GitAuthHelper):
                     "  %s = deploykey_%s_%s"
                     % (
                         access,
-                        werkzeug.secure_filename(project.fullname),
+                        werkzeug.utils.secure_filename(project.fullname),
                         deploykey.id,
                     )
                 )
@@ -703,11 +704,11 @@ class Gitolite2Auth(GitAuthHelper):
         of lines as returned by _process_project.
         """
         repos = []
-        for l in lines:
-            if l.startswith("repo "):
-                repos.append([l])
+        for line in lines:
+            if line.startswith("repo "):
+                repos.append([line])
             else:
-                repos[-1].append(l)
+                repos[-1].append(line)
         for i, repo_lines in enumerate(repos):
             repos[i] = "\n".join(repo_lines)
         return repos
@@ -896,8 +897,13 @@ class PagureGitAuth(GitAuthHelper):
                 self.info("Pull request required")
                 return False
 
+        if username is None:
+            return False
+
         # Determine whether the current user is allowed to push
-        is_committer = is_repo_committer(project, username, session)
+        is_committer = is_repo_collaborator(
+            project, refname, username, session
+        )
         deploykey = lookup_deploykey(project, username)
         if deploykey is not None:
             self.info("Deploykey used. Push access: %s" % deploykey.pushaccess)
