@@ -213,7 +213,14 @@ def delete_project(
 @conn.task(queue=pagure_config.get("FAST_CELERY_QUEUE", None), bind=True)
 @pagure_task
 def create_project(
-    self, session, username, namespace, name, add_readme, ignore_existing_repo
+    self,
+    session,
+    username,
+    namespace,
+    name,
+    add_readme,
+    ignore_existing_repo,
+    default_branch=None,
 ):
     """ Create a project.
 
@@ -231,6 +238,9 @@ def create_project(
     :kwarg ignore_existing_repo: a boolean specifying whether the creation
         of the project should fail if the repo exists on disk or not
     :type ignore_existing_repo: bool
+    :kwarg default_branch: the name of the default branch to create and set
+        as default.
+    :type default_branch: str or None
 
     """
     project = pagure.lib.query._get_project(
@@ -272,12 +282,19 @@ def create_project(
         session.commit()
         raise
 
+    if default_branch:
+        path = project.repopath("main")
+        repo_obj = pygit2.Repository(path)
+        repo_obj.set_head("refs/heads/%s" % default_branch)
+
     if add_readme:
         with project.lock("WORKER"):
             with pagure.lib.git.TemporaryClone(
                 project, "main", "add_readme"
             ) as tempclone:
                 temp_gitrepo = tempclone.repo
+                if default_branch:
+                    temp_gitrepo.set_head("refs/heads/%s" % default_branch)
 
                 # Add README file
                 author = userobj.fullname or userobj.user
@@ -1117,7 +1134,8 @@ def pull_request_ready_branch(self, session, namespace, name, user):
     repo = pagure.lib.query._get_project(
         session, name, user=user, namespace=namespace
     )
-    repo_obj = pygit2.Repository(pagure.utils.get_repo_path(repo))
+    repo_path = pagure.utils.get_repo_path(repo)
+    repo_obj = pygit2.Repository(repo_path)
 
     if repo.is_fork and repo.parent:
         parentreponame = pagure.utils.get_repo_path(repo.parent)
@@ -1127,7 +1145,13 @@ def pull_request_ready_branch(self, session, namespace, name, user):
 
     branches = {}
     if not repo_obj.is_empty and len(repo_obj.listall_branches()) > 0:
-        for branchname in repo_obj.listall_branches():
+        branch_names = (
+            pagure.lib.repo.PagureRepo.get_active_branches(
+                repo_path, catch_exception=True
+            )
+            or repo_obj.listall_branches()
+        )
+        for branchname in branch_names:
             compare_branch = None
             if (
                 not parent_repo_obj.is_empty
@@ -1241,3 +1265,51 @@ def generate_archive(
         namespace=project.namespace,
         username=project.user.user if project.is_fork else None,
     )
+
+
+@conn.task(queue=pagure_config.get("AUTHORIZED_KEYS_QUEUE", None), bind=True)
+@pagure_task
+def add_key_to_authorized_keys(self, session, ssh_folder, username, sshkey):
+    """ Add the specified key to the the `authorized_keys` file of the
+    specified ssh folder.
+    """
+    if not os.path.exists(ssh_folder):
+        _log.info("No folder '%s' found", ssh_folder)
+        return
+
+    fullpath = os.path.join(ssh_folder, "authorized_keys")
+    _log.info("Add ssh key for user %s to %s", username, fullpath)
+    with open(fullpath, "a") as stream:
+        stream.write("\n")
+        stream.write(
+            "{0} {1}".format(
+                pagure_config["SSH_KEYS_OPTIONS"] % {"username": username},
+                sshkey.strip(),
+            )
+        )
+    os.chmod(fullpath, 0o600)
+
+
+@conn.task(queue=pagure_config.get("AUTHORIZED_KEYS_QUEUE", None), bind=True)
+@pagure_task
+def remove_key_from_authorized_keys(self, session, ssh_folder, sshkey):
+    """ Remove the specified key from the the `authorized_keys` file of the
+    specified ssh folder.
+    """
+    if not os.path.exists(ssh_folder):
+        _log.info("No folder '%s' found", ssh_folder)
+        return
+
+    fullpath = os.path.join(ssh_folder, "authorized_keys")
+    _log.info("Removing ssh key in %s", fullpath)
+    output = []
+    with open(fullpath, "r") as stream:
+        for row in stream.readlines():
+            row = row.strip()
+            if sshkey in row:
+                continue
+            output.append(row)
+
+    with open(fullpath, "w") as stream:
+        stream.write("\n".join(output))
+    os.chmod(fullpath, 0o600)
