@@ -21,6 +21,7 @@ from sqlalchemy.exc import SQLAlchemyError
 import pagure.exceptions
 import pagure.lib.git
 import pagure.lib.query
+import pagure.lib.tasks
 import pagure.forms
 import pagure.ui.filters
 from pagure.config import config as pagure_config
@@ -159,11 +160,11 @@ def userdash_projects():
     groups = []
 
     for group in user.groups:
-        groups.append(
-            pagure.lib.query.search_groups(
-                flask.g.session, group_name=group, group_type="user"
-            )
+        group_obj = pagure.lib.query.search_groups(
+            flask.g.session, group_name=group, group_type="user"
         )
+        if group_obj:
+            groups.append(group_obj)
 
     acl = flask.request.args.get("acl", "").strip().lower() or None
     search_pattern = flask.request.args.get("search_pattern", None)
@@ -1073,6 +1074,7 @@ def new_project():
                 ),
                 user_ns=pagure_config.get("USER_NAMESPACE", False),
                 ignore_existing_repo=ignore_existing_repos,
+                default_branch=form.default_branch.data,
             )
             flask.g.session.commit()
             return pagure.utils.wait_for_task(task)
@@ -1201,6 +1203,16 @@ def add_user_sshkey():
                 user, pagure_config.get("GITOLITE_KEYDIR", None)
             )
             pagure.lib.tasks.gitolite_post_compile_only.delay()
+            if (
+                pagure_config.get("GIT_AUTH_BACKEND")
+                == "pagure_authorized_keys"
+            ):
+                _log.info("SSH FOLDER: %s", pagure_config.get("SSH_FOLDER"))
+                pagure.lib.tasks.add_key_to_authorized_keys.delay(
+                    ssh_folder=pagure_config.get("SSH_FOLDER"),
+                    username=flask.g.fas_user.username,
+                    sshkey=form.ssh_key.data,
+                )
             flask.flash(msg)
             return flask.redirect(
                 flask.url_for("ui_ns.user_settings") + "#nav-ssh-tab"
@@ -1234,8 +1246,10 @@ def remove_user_sshkey(keyid):
     if form.validate_on_submit():
         user = _get_user(username=flask.g.fas_user.username)
         found = False
+        sshkey = None
         for key in user.sshkeys:
             if key.id == keyid:
+                sshkey = key.public_ssh_key
                 flask.g.session.delete(key)
                 found = True
                 break
@@ -1252,6 +1266,14 @@ def remove_user_sshkey(keyid):
                 user, pagure_config.get("GITOLITE_KEYDIR", None)
             )
             pagure.lib.tasks.gitolite_post_compile_only.delay()
+            if (
+                pagure_config.get("GIT_AUTH_BACKEND")
+                == "pagure_authorized_keys"
+            ):
+                _log.info("SSH FOLDER: %s", pagure_config.get("SSH_FOLDER"))
+                pagure.lib.tasks.remove_key_from_authorized_keys.delay(
+                    ssh_folder=pagure_config.get("SSH_FOLDER"), sshkey=sshkey
+                )
             flask.flash("SSH key removed")
         except SQLAlchemyError as err:  # pragma: no cover
             flask.g.session.rollback()
@@ -1498,12 +1520,15 @@ def add_api_user_token():
                 description=form.description.data.strip() or None,
                 acls=form.acls.data,
                 username=user.username,
+                expiration_date=form.expiration_date.data,
             )
             flask.g.session.commit()
             flask.flash("Token created")
             return flask.redirect(
                 flask.url_for("ui_ns.user_settings") + "#nav-api-tab"
             )
+        except pagure.exceptions.PagureException as err:
+            flask.flash(str(err), "error")
         except SQLAlchemyError as err:  # pragma: no cover
             flask.g.session.rollback()
             _log.exception(err)
@@ -1555,6 +1580,51 @@ def revoke_api_user_token(token_id):
     )
 
 
+@UI_NS.route("/settings/token/renew/<token_id>/", methods=["POST"])
+@UI_NS.route("/settings/token/renew/<token_id>", methods=["POST"])
+@login_required
+def renew_api_user_token(token_id):
+    """ Renew a user token (ie: not project specific).
+    """
+    if admin_session_timedout():
+        flask.flash("Action canceled, try it again", "error")
+        url = flask.url_for(".user_settings")
+        return flask.redirect(flask.url_for("auth_login", next=url))
+
+    token = pagure.lib.query.get_api_token(flask.g.session, token_id)
+
+    if not token or token.user.username != flask.g.fas_user.username:
+        flask.abort(404, description="Token not found")
+
+    form = pagure.forms.ConfirmationForm()
+
+    if form.validate_on_submit():
+        acls = [acl.name for acl in token.acls]
+        try:
+            pagure.lib.query.add_token_to_user(
+                flask.g.session,
+                project=None,
+                description=token.description or None,
+                acls=acls,
+                username=flask.g.fas_user.username,
+                expiration_date=datetime.date.today()
+                + datetime.timedelta(days=(30 * 6)),
+            )
+            flask.g.session.commit()
+            flask.flash("Token created")
+            return flask.redirect(
+                flask.url_for("ui_ns.user_settings") + "#nav-api-tab"
+            )
+        except SQLAlchemyError as err:  # pragma: no cover
+            flask.g.session.rollback()
+            _log.exception(err)
+            flask.flash("API token could not be renewed", "error")
+
+    return flask.redirect(
+        flask.url_for("ui_ns.user_settings") + "#nav-api-tab"
+    )
+
+
 @UI_NS.route("/settings/forcelogout/", methods=("POST",))
 @UI_NS.route("/settings/forcelogout", methods=("POST",))
 @login_required
