@@ -17,12 +17,14 @@ from __future__ import unicode_literals, absolute_import
 
 import textwrap
 import logging
+import os
 from os.path import splitext
 
 import arrow
+import bleach
 import flask
 import six
-import bleach
+import pygit2
 
 from six.moves.urllib.parse import urlparse, parse_qsl
 from jinja2 import escape
@@ -374,7 +376,12 @@ def format_loc(
                     "%(comment)s"
                     "</div>"
                     "</section>"
-                    "</div></div>"
+                    "</div>"
+                    '<div class="card-footer bg-transparent d-flex '
+                    'align-items-center border-0 p-0">'
+                    "%(templ_edited)s"
+                    "</div>"
+                    "</div>"
                     "</td></tr>"
                     % (
                         {
@@ -813,6 +820,24 @@ def user_can_clone_ssh(username):
     return always_render or has_ssh_keys
 
 
+@UI_NS.app_template_filter("user_group_can_ssh_commit")
+def user_group_can_ssh_commit(username):
+    """ Returns whether the user is in a group that has ssh access. """
+    ssh_access_groups = pagure_config.get("SSH_ACCESS_GROUPS") or []
+    if not ssh_access_groups:
+        # ssh access is not restricted to one or more groups
+        return True
+
+    user_obj = pagure.lib.query.search_user(flask.g.session, username=username)
+    if not user_obj:
+        # user not found
+        return False
+
+    user_grps = set(user_obj.groups)
+    req_grps = set(pagure_config.get("SSH_ACCESS_GROUPS"))
+    return len(user_grps.intersection(req_grps)) > 0
+
+
 @UI_NS.app_template_filter("git_url_ssh")
 def get_git_url_ssh(complement=""):
     """ Return the GIT SSH URL to be displayed in the UI based on the
@@ -838,3 +863,25 @@ def get_patch_stats(patch):
         _log.exception("Failed to get stats on a patch")
         output = {}
     return output
+
+
+@UI_NS.app_template_filter("get_default_branch")
+def get_default_branch(repo):
+    """ Given a pygit2.Repository object, extracts the default branch. """
+    default_branch = None
+
+    try:
+        default_branch = repo.head.shorthand
+    except pygit2.GitError:
+        pass
+
+    if not default_branch:
+        path = repo.path
+        path_head = os.path.join(path, "HEAD")
+        if os.path.exists(path_head):
+            with open(path_head) as stream:
+                data = stream.read().strip()
+            if data:
+                default_branch = data.split("refs/heads/", 1)[-1]
+
+    return default_branch
