@@ -333,6 +333,37 @@ def update_issue(repo, issueid, username=None, namespace=None):
                 )
                 messages = messages.union(set(msgs))
 
+                # Update the boards the ticket is in
+                in_boards = set()
+                for board in repo.boards:
+                    if board.tag.tag in tags:
+                        in_boards.add(board)
+                cur_boards = set([bi.board for bi in issue.boards_issues])
+
+                add_boards = in_boards - cur_boards
+                _log.info("Adding issue to boards: %s", add_boards)
+                for board in add_boards:
+                    if board.active:
+                        pagure.lib.query.update_ticket_board_status(
+                            flask.g.session,
+                            board=board,
+                            user=flask.g.fas_user.username,
+                            rank=None,
+                            status_name=None,
+                            ticket_uid=issue.uid,
+                        )
+                    else:
+                        _log.debug("Skipping inactive board %s", board)
+
+                rm_boards = cur_boards - in_boards
+                _log.info("Removing issue from boards: %s", rm_boards)
+                pagure.lib.query.remove_issue_from_boards(
+                    flask.g.session,
+                    issue=issue,
+                    board_names=[b.name for b in rm_boards],
+                    user=flask.g.fas_user.username,
+                )
+
             flask.g.session.commit()
 
             # New comment
@@ -999,6 +1030,7 @@ def new_issue(repo, username=None, namespace=None):
 
     types = None
     default = None
+    contributing = None
     ticketrepopath = repo.repopath("tickets")
     if os.path.exists(ticketrepopath):
         ticketrepo = pygit2.Repository(ticketrepopath)
@@ -1009,7 +1041,11 @@ def new_issue(repo, username=None, namespace=None):
                 ticketrepo, commit.tree, ["templates"], bail_on_tree=True
             )
             if files:
-                types = [f.name.rsplit(".md", 1)[0] for f in files]
+                types = [
+                    f.name.rsplit(".md", 1)[0]
+                    for f in files
+                    if f.name not in ["contributing.md"]
+                ]
 
             default_file = None
             if types and template in types:
@@ -1025,6 +1061,17 @@ def new_issue(repo, username=None, namespace=None):
                     default_file.data, "md"
                 )
 
+            contributing = __get_file_in_tree(
+                ticketrepo,
+                commit.tree,
+                ["templates", "contributing.md"],
+                bail_on_tree=True,
+            )
+            if contributing:
+                contributing, _ = pagure.doc_utils.convert_readme(
+                    contributing.data, "md"
+                )
+
     tag_list = pagure.lib.query.get_tags_of_project(flask.g.session, repo)
     if flask.request.method == "GET":
         form.private.data = repo.settings.get(
@@ -1051,6 +1098,7 @@ def new_issue(repo, username=None, namespace=None):
         default=default,
         tag_list=tag_list,
         open_access=open_access,
+        contributing=contributing,
     )
 
 
