@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 """
- (c) 2017 - Copyright Red Hat Inc
+ (c) 2017-2020 - Copyright Red Hat Inc
 
  Authors:
    Pierre-Yves Chibon <pingou@pingoured.fr>
@@ -11,6 +11,7 @@
 from __future__ import unicode_literals, absolute_import
 
 import datetime
+import fnmatch
 import logging
 import logging.config
 import os
@@ -21,7 +22,7 @@ from functools import wraps
 import flask
 import pygit2
 import six
-import werkzeug
+import werkzeug.utils
 
 from pagure.exceptions import (
     PagureException,
@@ -35,14 +36,14 @@ _log = logging.getLogger(__name__)
 LOGGER_SETUP = False
 
 
-def set_up_logging(app=None, force=False):
+def set_up_logging(app=None, force=False, configkey="LOGGING"):
     global LOGGER_SETUP
     if LOGGER_SETUP and not force:
         _log.info("logging already setup")
         return
 
     logging.basicConfig()
-    logging.config.dictConfig(pagure_config.get("LOGGING") or {"version": 1})
+    logging.config.dictConfig(pagure_config.get(configkey) or {"version": 1})
 
     LOGGER_SETUP = True
 
@@ -50,7 +51,13 @@ def set_up_logging(app=None, force=False):
 def authenticated():
     """ Utility function checking if the current user is logged in or not.
     """
-    return hasattr(flask.g, "fas_user") and flask.g.fas_user is not None
+    fas_user = None
+    try:
+        fas_user = flask.g.fas_user
+    except (RuntimeError, AttributeError):
+        pass
+
+    return fas_user is not None
 
 
 def api_authenticated():
@@ -68,6 +75,9 @@ def api_authenticated():
 def check_api_acls(acls, optional=False):
     """ Checks if the user provided an API token with its request and if
     this token allows the user to access the endpoint desired.
+
+    :arg acls: A list of access control
+    :arg optional: Only check the API token is valid. Skip the ACL validation.
     """
     import pagure.api
     import pagure.lib.query
@@ -260,6 +270,63 @@ def is_repo_committer(repo_obj, username=None, session=None):
     return False
 
 
+def is_repo_collaborator(repo_obj, refname, username=None, session=None):
+    """ Return whether the user has commit on the specified branch of the
+    provided repo. """
+    committer = is_repo_committer(repo_obj, username=username, session=session)
+    if committer:
+        _log.debug("User is a committer")
+        return committer
+
+    import pagure.lib.query
+
+    if username is None:
+        if not authenticated():
+            return False
+        if is_admin():
+            return True
+        username = flask.g.fas_user.username
+        usergroups = set(flask.g.fas_user.groups)
+
+    if not session:
+        session = flask.g.session
+    try:
+        user = pagure.lib.query.get_user(session, username)
+        usergroups = set(user.groups)
+    except pagure.exceptions.PagureException:
+        return False
+
+    # If they are in the list of committers -> maybe
+    for user in repo_obj.collaborators:
+        if user.user.username == username:
+            # if branch is None when the user tries to read,
+            # so we'll allow that
+            if refname is None:
+                return True
+            # If the branch is specified: the user is trying to write, we'll
+            # check if they are allowed to
+            for pattern in user.branches.split(","):
+                pattern = "refs/heads/{}".format(pattern.strip())
+                if fnmatch.fnmatch(refname, pattern):
+                    return True
+
+    # If they are in a group that has commit access -> maybe
+    for project_group in repo_obj.collaborator_groups:
+        if project_group.group.group_name in usergroups:
+            # if branch is None when the user tries to read,
+            # so we'll allow that
+            if refname is None:
+                return True
+            # If the branch is specified: the user is trying to write, we'll
+            # check if they are allowed to
+            for pattern in project_group.branches.split(","):
+                pattern = "refs/heads/{}".format(pattern.strip())
+                if fnmatch.fnmatch(refname, pattern):
+                    return True
+
+    return False
+
+
 def is_repo_user(repo_obj, username=None):
     """ Return whether the user has some access in the provided repo. """
     if username:
@@ -592,7 +659,7 @@ def get_remote_repo_path(remote_git, branch_from, ignore_non_exist=False):
     """
     repopath = os.path.join(
         pagure_config["REMOTE_GIT_FOLDER"],
-        werkzeug.secure_filename("%s_%s" % (remote_git, branch_from)),
+        werkzeug.utils.secure_filename("%s_%s" % (remote_git, branch_from)),
     )
 
     if not os.path.exists(repopath) and not ignore_non_exist:
@@ -784,7 +851,7 @@ def lookup_deploykey(project, username):
         return None
     username = username[len("deploykey_") :]
     rest, keyid = username.rsplit("_", 1)
-    if rest != werkzeug.secure_filename(project.fullname):
+    if rest != werkzeug.utils.secure_filename(project.fullname):
         # This is not a deploykey for the specified project
         return None
     keyid = int(keyid)
