@@ -256,9 +256,15 @@ class PagureFlaskApiForkUpdatetests(tests.SimplePagureTest):
                 "initial_comment": "Edited initial comment",
                 "last_updated": "1551276261",
                 "project": {
-                    "access_groups": {"admin": [], "commit": [], "ticket": []},
+                    "access_groups": {
+                        "admin": [],
+                        "collaborator": [],
+                        "commit": [],
+                        "ticket": [],
+                    },
                     "access_users": {
                         "admin": [],
+                        "collaborator": [],
                         "commit": [],
                         "owner": ["pingou"],
                         "ticket": [],
@@ -282,13 +288,23 @@ class PagureFlaskApiForkUpdatetests(tests.SimplePagureTest):
                     "priorities": {},
                     "tags": [],
                     "url_path": "test",
-                    "user": {"fullname": "PY C", "name": "pingou"},
+                    "user": {
+                        "fullname": "PY C",
+                        "name": "pingou",
+                        "url_path": "user/pingou",
+                    },
                 },
                 "remote_git": None,
                 "repo_from": {
-                    "access_groups": {"admin": [], "commit": [], "ticket": []},
+                    "access_groups": {
+                        "admin": [],
+                        "collaborator": [],
+                        "commit": [],
+                        "ticket": [],
+                    },
                     "access_users": {
                         "admin": [],
+                        "collaborator": [],
                         "commit": [],
                         "owner": ["pingou"],
                         "ticket": [],
@@ -306,11 +322,13 @@ class PagureFlaskApiForkUpdatetests(tests.SimplePagureTest):
                     "parent": {
                         "access_groups": {
                             "admin": [],
+                            "collaborator": [],
                             "commit": [],
                             "ticket": [],
                         },
                         "access_users": {
                             "admin": [],
+                            "collaborator": [],
                             "commit": [],
                             "owner": ["pingou"],
                             "ticket": [],
@@ -334,12 +352,20 @@ class PagureFlaskApiForkUpdatetests(tests.SimplePagureTest):
                         "priorities": {},
                         "tags": [],
                         "url_path": "test",
-                        "user": {"fullname": "PY C", "name": "pingou"},
+                        "user": {
+                            "fullname": "PY C",
+                            "name": "pingou",
+                            "url_path": "user/pingou",
+                        },
                     },
                     "priorities": {},
                     "tags": [],
                     "url_path": "fork/pingou/test",
-                    "user": {"fullname": "PY C", "name": "pingou"},
+                    "user": {
+                        "fullname": "PY C",
+                        "name": "pingou",
+                        "url_path": "user/pingou",
+                    },
                 },
                 "status": "Open",
                 "tags": [],
@@ -347,7 +373,11 @@ class PagureFlaskApiForkUpdatetests(tests.SimplePagureTest):
                 "title": "edited test PR",
                 "uid": "a2bddecc8ea548e88c22a0df77670092",
                 "updated_on": "1551276260",
-                "user": {"fullname": "PY C", "name": "pingou"},
+                "user": {
+                    "fullname": "PY C",
+                    "name": "pingou",
+                    "url_path": "user/pingou",
+                },
             },
         )
 
@@ -396,9 +426,15 @@ class PagureFlaskApiForkUpdatetests(tests.SimplePagureTest):
                 "initial_comment": "",
                 "last_updated": "1551276261",
                 "project": {
-                    "access_groups": {"admin": [], "commit": [], "ticket": []},
+                    "access_groups": {
+                        "admin": [],
+                        "collaborator": [],
+                        "commit": [],
+                        "ticket": [],
+                    },
                     "access_users": {
                         "admin": [],
+                        "collaborator": [],
                         "commit": [],
                         "owner": ["pingou"],
                         "ticket": [],
@@ -422,13 +458,23 @@ class PagureFlaskApiForkUpdatetests(tests.SimplePagureTest):
                     "priorities": {},
                     "tags": [],
                     "url_path": "test",
-                    "user": {"fullname": "PY C", "name": "pingou"},
+                    "user": {
+                        "fullname": "PY C",
+                        "name": "pingou",
+                        "url_path": "user/pingou",
+                    },
                 },
                 "remote_git": None,
                 "repo_from": {
-                    "access_groups": {"admin": [], "commit": [], "ticket": []},
+                    "access_groups": {
+                        "admin": [],
+                        "collaborator": [],
+                        "commit": [],
+                        "ticket": [],
+                    },
                     "access_users": {
                         "admin": [],
+                        "collaborator": [],
                         "commit": [],
                         "owner": ["pingou"],
                         "ticket": [],
@@ -446,11 +492,13 @@ class PagureFlaskApiForkUpdatetests(tests.SimplePagureTest):
                     "parent": {
                         "access_groups": {
                             "admin": [],
+                            "collaborator": [],
                             "commit": [],
                             "ticket": [],
                         },
                         "access_users": {
                             "admin": [],
+                            "collaborator": [],
                             "commit": [],
                             "owner": ["pingou"],
                             "ticket": [],
@@ -474,12 +522,20 @@ class PagureFlaskApiForkUpdatetests(tests.SimplePagureTest):
                         "priorities": {},
                         "tags": [],
                         "url_path": "test",
-                        "user": {"fullname": "PY C", "name": "pingou"},
+                        "user": {
+                            "fullname": "PY C",
+                            "name": "pingou",
+                            "url_path": "user/pingou",
+                        },
                     },
                     "priorities": {},
                     "tags": [],
                     "url_path": "fork/pingou/test",
-                    "user": {"fullname": "PY C", "name": "pingou"},
+                    "user": {
+                        "fullname": "PY C",
+                        "name": "pingou",
+                        "url_path": "user/pingou",
+                    },
                 },
                 "status": "Open",
                 "tags": [],
@@ -487,7 +543,11 @@ class PagureFlaskApiForkUpdatetests(tests.SimplePagureTest):
                 "title": "edited test PR",
                 "uid": "a2bddecc8ea548e88c22a0df77670092",
                 "updated_on": "1551276260",
-                "user": {"fullname": "PY C", "name": "pingou"},
+                "user": {
+                    "fullname": "PY C",
+                    "name": "pingou",
+                    "url_path": "user/pingou",
+                },
             },
         )
 
@@ -556,9 +616,15 @@ class PagureFlaskApiForkUpdatetests(tests.SimplePagureTest):
                 "fixes #2 \n\nThanks",
                 "last_updated": "1551276261",
                 "project": {
-                    "access_groups": {"admin": [], "commit": [], "ticket": []},
+                    "access_groups": {
+                        "admin": [],
+                        "collaborator": [],
+                        "commit": [],
+                        "ticket": [],
+                    },
                     "access_users": {
                         "admin": [],
+                        "collaborator": [],
                         "commit": [],
                         "owner": ["pingou"],
                         "ticket": [],
@@ -582,13 +648,23 @@ class PagureFlaskApiForkUpdatetests(tests.SimplePagureTest):
                     "priorities": {},
                     "tags": [],
                     "url_path": "test",
-                    "user": {"fullname": "PY C", "name": "pingou"},
+                    "user": {
+                        "fullname": "PY C",
+                        "name": "pingou",
+                        "url_path": "user/pingou",
+                    },
                 },
                 "remote_git": None,
                 "repo_from": {
-                    "access_groups": {"admin": [], "commit": [], "ticket": []},
+                    "access_groups": {
+                        "admin": [],
+                        "collaborator": [],
+                        "commit": [],
+                        "ticket": [],
+                    },
                     "access_users": {
                         "admin": [],
+                        "collaborator": [],
                         "commit": [],
                         "owner": ["pingou"],
                         "ticket": [],
@@ -606,11 +682,13 @@ class PagureFlaskApiForkUpdatetests(tests.SimplePagureTest):
                     "parent": {
                         "access_groups": {
                             "admin": [],
+                            "collaborator": [],
                             "commit": [],
                             "ticket": [],
                         },
                         "access_users": {
                             "admin": [],
+                            "collaborator": [],
                             "commit": [],
                             "owner": ["pingou"],
                             "ticket": [],
@@ -634,12 +712,20 @@ class PagureFlaskApiForkUpdatetests(tests.SimplePagureTest):
                         "priorities": {},
                         "tags": [],
                         "url_path": "test",
-                        "user": {"fullname": "PY C", "name": "pingou"},
+                        "user": {
+                            "fullname": "PY C",
+                            "name": "pingou",
+                            "url_path": "user/pingou",
+                        },
                     },
                     "priorities": {},
                     "tags": [],
                     "url_path": "fork/pingou/test",
-                    "user": {"fullname": "PY C", "name": "pingou"},
+                    "user": {
+                        "fullname": "PY C",
+                        "name": "pingou",
+                        "url_path": "user/pingou",
+                    },
                 },
                 "status": "Open",
                 "tags": [],
@@ -647,7 +733,11 @@ class PagureFlaskApiForkUpdatetests(tests.SimplePagureTest):
                 "title": "edited test PR",
                 "uid": "a2bddecc8ea548e88c22a0df77670092",
                 "updated_on": "1551276260",
-                "user": {"fullname": "PY C", "name": "pingou"},
+                "user": {
+                    "fullname": "PY C",
+                    "name": "pingou",
+                    "url_path": "user/pingou",
+                },
             },
         )
 
