@@ -84,7 +84,7 @@ class PagureFlaskApiGroupTests(tests.SimplePagureTest):
         output = self.app.get("/api/0/groups")
         self.assertEqual(output.status_code, 200)
         data = json.loads(output.get_data(as_text=True))
-        self.assertEqual(data["groups"], ["some_group", "group1", "rel-eng"])
+        self.assertEqual(data["groups"], ["group1", "rel-eng", "some_group"])
         self.assertEqual(
             sorted(data.keys()), ["groups", "pagination", "total_groups"]
         )
@@ -130,9 +130,9 @@ class PagureFlaskApiGroupTests(tests.SimplePagureTest):
             data,
             {
                 "groups": [
-                    {"description": None, "name": "some_group"},
                     {"description": None, "name": "group1"},
                     {"description": None, "name": "rel-eng"},
+                    {"description": None, "name": "some_group"},
                 ],
                 "pagination": {
                     "first": "http://localhost...",
@@ -162,6 +162,7 @@ class PagureFlaskApiGroupTests(tests.SimplePagureTest):
             "description": None,
             "creator": {
                 "fullname": "PY C",
+                "url_path": "user/pingou",
                 "default_email": "bar@pingou.com",
                 "emails": ["bar@pingou.com", "foo@pingou.com"],
                 "name": "pingou",
@@ -185,7 +186,11 @@ class PagureFlaskApiGroupTests(tests.SimplePagureTest):
         exp = {
             "display_name": "Some Group",
             "description": None,
-            "creator": {"fullname": "PY C", "name": "pingou"},
+            "creator": {
+                "fullname": "PY C",
+                "name": "pingou",
+                "url_path": "user/pingou",
+            },
             "members": ["pingou"],
             "date_created": "1492020239",
             "group_type": "user",
@@ -232,6 +237,7 @@ class PagureFlaskApiGroupTests(tests.SimplePagureTest):
                 "default_email": "bar@pingou.com",
                 "emails": ["bar@pingou.com", "foo@pingou.com"],
                 "name": "pingou",
+                "url_path": "user/pingou",
             },
             "members": ["pingou", "mprahl"],
             "date_created": "1492020239",
@@ -274,6 +280,7 @@ class PagureFlaskApiGroupTests(tests.SimplePagureTest):
                 "default_email": "bar@pingou.com",
                 "emails": ["bar@pingou.com", "foo@pingou.com"],
                 "name": "pingou",
+                "url_path": "user/pingou",
             },
             "members": ["pingou"],
             "date_created": "1492020239",
@@ -283,11 +290,13 @@ class PagureFlaskApiGroupTests(tests.SimplePagureTest):
                 {
                     "access_groups": {
                         "admin": ["some_group"],
+                        "collaborator": [],
                         "commit": [],
                         "ticket": [],
                     },
                     "access_users": {
                         "admin": [],
+                        "collaborator": [],
                         "commit": [],
                         "owner": ["pingou"],
                         "ticket": [],
@@ -311,7 +320,11 @@ class PagureFlaskApiGroupTests(tests.SimplePagureTest):
                     "priorities": {},
                     "tags": [],
                     "url_path": "test2",
-                    "user": {"fullname": "PY C", "name": "pingou"},
+                    "user": {
+                        "fullname": "PY C",
+                        "name": "pingou",
+                        "url_path": "user/pingou",
+                    },
                 }
             ],
         }
@@ -344,7 +357,11 @@ class PagureFlaskApiGroupTests(tests.SimplePagureTest):
         exp = {
             "display_name": "Some Group",
             "description": None,
-            "creator": {"fullname": "PY C", "name": "pingou"},
+            "creator": {
+                "fullname": "PY C",
+                "name": "pingou",
+                "url_path": "user/pingou",
+            },
             "members": ["pingou"],
             "date_created": "1492020239",
             "group_type": "user",
@@ -353,11 +370,13 @@ class PagureFlaskApiGroupTests(tests.SimplePagureTest):
                 {
                     "access_groups": {
                         "admin": ["some_group"],
+                        "collaborator": [],
                         "commit": [],
                         "ticket": [],
                     },
                     "access_users": {
                         "admin": [],
+                        "collaborator": [],
                         "commit": [],
                         "owner": ["pingou"],
                         "ticket": [],
@@ -381,7 +400,11 @@ class PagureFlaskApiGroupTests(tests.SimplePagureTest):
                     "priorities": {},
                     "tags": [],
                     "url_path": "test2",
-                    "user": {"fullname": "PY C", "name": "pingou"},
+                    "user": {
+                        "fullname": "PY C",
+                        "name": "pingou",
+                        "url_path": "user/pingou",
+                    },
                 }
             ],
         }
@@ -406,7 +429,11 @@ class PagureFlaskApiGroupTests(tests.SimplePagureTest):
         exp = {
             "display_name": "Some Group",
             "description": None,
-            "creator": {"fullname": "PY C", "name": "pingou"},
+            "creator": {
+                "fullname": "PY C",
+                "name": "pingou",
+                "url_path": "user/pingou",
+            },
             "members": ["pingou"],
             "date_created": "1492020239",
             "group_type": "user",
@@ -415,11 +442,13 @@ class PagureFlaskApiGroupTests(tests.SimplePagureTest):
                 {
                     "access_groups": {
                         "admin": ["some_group"],
+                        "collaborator": [],
                         "commit": [],
                         "ticket": [],
                     },
                     "access_users": {
                         "admin": [],
+                        "collaborator": [],
                         "commit": [],
                         "owner": ["pingou"],
                         "ticket": [],
@@ -443,7 +472,11 @@ class PagureFlaskApiGroupTests(tests.SimplePagureTest):
                     "priorities": {},
                     "tags": [],
                     "url_path": "test2",
-                    "user": {"fullname": "PY C", "name": "pingou"},
+                    "user": {
+                        "fullname": "PY C",
+                        "name": "pingou",
+                        "url_path": "user/pingou",
+                    },
                 }
             ],
         }
@@ -480,7 +513,11 @@ class PagureFlaskApiGroupTests(tests.SimplePagureTest):
         exp = {
             "display_name": "Some Group",
             "description": None,
-            "creator": {"fullname": "PY C", "name": "pingou"},
+            "creator": {
+                "fullname": "PY C",
+                "name": "pingou",
+                "url_path": "user/pingou",
+            },
             "members": ["pingou"],
             "date_created": "1492020239",
             "group_type": "user",
@@ -514,7 +551,11 @@ class PagureFlaskApiGroupTests(tests.SimplePagureTest):
         exp = {
             "display_name": "Some Group",
             "description": None,
-            "creator": {"fullname": "PY C", "name": "pingou"},
+            "creator": {
+                "fullname": "PY C",
+                "name": "pingou",
+                "url_path": "user/pingou",
+            },
             "members": ["pingou"],
             "date_created": "1492020239",
             "group_type": "user",
@@ -546,7 +587,11 @@ class PagureFlaskApiGroupTests(tests.SimplePagureTest):
         exp = {
             "display_name": "Release engineering group",
             "description": None,
-            "creator": {"fullname": "PY C", "name": "pingou"},
+            "creator": {
+                "fullname": "PY C",
+                "name": "pingou",
+                "url_path": "user/pingou",
+            },
             "members": [],
             "date_created": "1492020239",
             "group_type": "user",
