@@ -263,6 +263,7 @@ class PagureFlaskApiPRFlagtests(tests.Modeltests):
                         "emails": ["bar@pingou.com", "foo@pingou.com"],
                         "fullname": "PY C",
                         "name": "pingou",
+                        "url_path": "user/pingou",
                     },
                     "username": "Jenkins",
                 },
@@ -334,6 +335,7 @@ class PagureFlaskApiPRFlagtests(tests.Modeltests):
                         "emails": ["bar@pingou.com", "foo@pingou.com"],
                         "fullname": "PY C",
                         "name": "pingou",
+                        "url_path": "user/pingou",
                     },
                     "username": "Jenkins",
                 },
@@ -387,6 +389,7 @@ class PagureFlaskApiPRFlagtests(tests.Modeltests):
                         "emails": ["bar@pingou.com", "foo@pingou.com"],
                         "fullname": "PY C",
                         "name": "pingou",
+                        "url_path": "user/pingou",
                     },
                     "username": "Jenkins",
                 },
@@ -445,6 +448,7 @@ class PagureFlaskApiPRFlagtests(tests.Modeltests):
                         "emails": ["bar@pingou.com", "foo@pingou.com"],
                         "fullname": "PY C",
                         "name": "pingou",
+                        "url_path": "user/pingou",
                     },
                     "username": "Jenkins",
                 },
@@ -498,6 +502,7 @@ class PagureFlaskApiPRFlagtests(tests.Modeltests):
                         "emails": ["bar@pingou.com", "foo@pingou.com"],
                         "fullname": "PY C",
                         "name": "pingou",
+                        "url_path": "user/pingou",
                     },
                     "username": "Jenkins",
                 },
@@ -800,6 +805,7 @@ class PagureFlaskApiPRFlagUserTokentests(tests.Modeltests):
                         "emails": ["bar@pingou.com", "foo@pingou.com"],
                         "fullname": "PY C",
                         "name": "pingou",
+                        "url_path": "user/pingou",
                     },
                     "username": "Jenkins",
                 },
@@ -861,6 +867,7 @@ class PagureFlaskApiPRFlagUserTokentests(tests.Modeltests):
                         "emails": ["bar@pingou.com", "foo@pingou.com"],
                         "fullname": "PY C",
                         "name": "pingou",
+                        "url_path": "user/pingou",
                     },
                     "username": "Jenkins",
                 },
@@ -915,6 +922,7 @@ class PagureFlaskApiPRFlagUserTokentests(tests.Modeltests):
                         "emails": ["bar@pingou.com", "foo@pingou.com"],
                         "fullname": "PY C",
                         "name": "pingou",
+                        "url_path": "user/pingou",
                     },
                     "username": "Jenkins",
                 },
@@ -1076,7 +1084,11 @@ class PagureFlaskApiGetPRFlagtests(tests.Modeltests):
                         "pull_request_uid": "72a61033c2fc464aa9ef514c057aa62c",
                         "status": "success",
                         "url": "http://jenkins.cloud.fedoraproject.org",
-                        "user": {"fullname": "foo bar", "name": "foo"},
+                        "user": {
+                            "fullname": "foo bar",
+                            "name": "foo",
+                            "url_path": "user/foo",
+                        },
                         "username": "jenkins",
                     }
                 ]
@@ -1150,7 +1162,11 @@ class PagureFlaskApiGetPRFlagtests(tests.Modeltests):
                         "pull_request_uid": "72a61033c2fc464aa9ef514c057aa62c",
                         "status": "pending",
                         "url": "http://travis.io",
-                        "user": {"fullname": "foo bar", "name": "foo"},
+                        "user": {
+                            "fullname": "foo bar",
+                            "name": "foo",
+                            "url_path": "user/foo",
+                        },
                         "username": "travis",
                     },
                     {
@@ -1161,7 +1177,11 @@ class PagureFlaskApiGetPRFlagtests(tests.Modeltests):
                         "pull_request_uid": "72a61033c2fc464aa9ef514c057aa62c",
                         "status": "success",
                         "url": "http://jenkins.cloud.fedoraproject.org",
-                        "user": {"fullname": "foo bar", "name": "foo"},
+                        "user": {
+                            "fullname": "foo bar",
+                            "name": "foo",
+                            "url_path": "user/foo",
+                        },
                         "username": "jenkins",
                     },
                 ]
