@@ -94,6 +94,7 @@ class PagureFlaskApiUSertests(tests.Modeltests):
             "user": {
                 "fullname": "PY C",
                 "name": "pingou",
+                "url_path": "user/pingou",
                 "avatar_url": "https://seccdn.libravatar.org/avatar/...",
             },
         }
@@ -138,9 +139,15 @@ class PagureFlaskApiUSertests(tests.Modeltests):
             },
             "repos": [
                 {
-                    "access_groups": {"admin": [], "commit": [], "ticket": []},
+                    "access_groups": {
+                        "admin": [],
+                        "collaborator": [],
+                        "commit": [],
+                        "ticket": [],
+                    },
                     "access_users": {
                         "admin": [],
+                        "collaborator": [],
                         "commit": [],
                         "owner": ["pingou"],
                         "ticket": [],
@@ -164,12 +171,22 @@ class PagureFlaskApiUSertests(tests.Modeltests):
                     "parent": None,
                     "priorities": {},
                     "tags": [],
-                    "user": {"fullname": "PY C", "name": "pingou"},
+                    "user": {
+                        "fullname": "PY C",
+                        "name": "pingou",
+                        "url_path": "user/pingou",
+                    },
                 },
                 {
-                    "access_groups": {"admin": [], "commit": [], "ticket": []},
+                    "access_groups": {
+                        "admin": [],
+                        "collaborator": [],
+                        "commit": [],
+                        "ticket": [],
+                    },
                     "access_users": {
                         "admin": [],
+                        "collaborator": [],
                         "commit": [],
                         "owner": ["pingou"],
                         "ticket": [],
@@ -193,12 +210,22 @@ class PagureFlaskApiUSertests(tests.Modeltests):
                     "parent": None,
                     "priorities": {},
                     "tags": [],
-                    "user": {"fullname": "PY C", "name": "pingou"},
+                    "user": {
+                        "fullname": "PY C",
+                        "name": "pingou",
+                        "url_path": "user/pingou",
+                    },
                 },
                 {
-                    "access_groups": {"admin": [], "commit": [], "ticket": []},
+                    "access_groups": {
+                        "admin": [],
+                        "collaborator": [],
+                        "commit": [],
+                        "ticket": [],
+                    },
                     "access_users": {
                         "admin": [],
+                        "collaborator": [],
                         "commit": [],
                         "owner": ["pingou"],
                         "ticket": [],
@@ -222,7 +249,11 @@ class PagureFlaskApiUSertests(tests.Modeltests):
                     "parent": None,
                     "priorities": {},
                     "tags": [],
-                    "user": {"fullname": "PY C", "name": "pingou"},
+                    "user": {
+                        "fullname": "PY C",
+                        "name": "pingou",
+                        "url_path": "user/pingou",
+                    },
                 },
             ],
             "repos_pagination": {
@@ -237,6 +268,7 @@ class PagureFlaskApiUSertests(tests.Modeltests):
             "user": {
                 "fullname": "PY C",
                 "name": "pingou",
+                "url_path": "user/pingou",
                 "avatar_url": "https://seccdn.libravatar.org/avatar/...",
             },
         }
@@ -331,7 +363,18 @@ class PagureFlaskApiUSertests(tests.Modeltests):
         # Invalid date, arrow >= 0.15 throws an exception,
         # previous versions parsed it
         output = self.app.get("/api/0/user/pingou/activity/2016asd")
-        if self.get_arrow_version() >= (0, 15):
+        arrow_version = self.get_arrow_version()
+        if arrow_version >= (0, 15, 6):
+            self.assertEqual(output.status_code, 400)
+            exp = {
+                "error": "Could not match input '2016asd' to any of the following formats: "
+                "YYYY-MM-DD, YYYY-M-DD, YYYY-M-D, YYYY/MM/DD, YYYY/M/DD, YYYY/M/D, "
+                "YYYY.MM.DD, YYYY.M.DD, YYYY.M.D, YYYYMMDD, YYYY-DDDD, YYYYDDDD, "
+                "YYYY-MM, YYYY/MM, YYYY.MM, YYYY, W",
+                "error_code": "ENOCODE",
+            }
+            self.assertEqual(json.loads(output.get_data(as_text=True)), exp)
+        elif arrow_version >= (0, 15):
             self.assertEqual(output.status_code, 400)
             exp = {
                 "error": "Could not match input '2016asd' to any of the following formats: "
@@ -376,7 +419,11 @@ class PagureFlaskApiUSertests(tests.Modeltests):
                     "id": 1,
                     "ref_id": "1",
                     "type": "created",
-                    "user": {"fullname": "PY C", "name": "pingou"},
+                    "user": {
+                        "fullname": "PY C",
+                        "name": "pingou",
+                        "url_path": "user/pingou",
+                    },
                 },
                 {
                     "date": date,
@@ -386,7 +433,11 @@ class PagureFlaskApiUSertests(tests.Modeltests):
                     "id": 2,
                     "ref_id": "1",
                     "type": "commented",
-                    "user": {"fullname": "PY C", "name": "pingou"},
+                    "user": {
+                        "fullname": "PY C",
+                        "name": "pingou",
+                        "url_path": "user/pingou",
+                    },
                 },
                 {
                     "date": date,
@@ -396,7 +447,11 @@ class PagureFlaskApiUSertests(tests.Modeltests):
                     "id": 3,
                     "ref_id": "1",
                     "type": "closed",
-                    "user": {"fullname": "PY C", "name": "pingou"},
+                    "user": {
+                        "fullname": "PY C",
+                        "name": "pingou",
+                        "url_path": "user/pingou",
+                    },
                 },
                 {
                     "date": date,
@@ -406,7 +461,11 @@ class PagureFlaskApiUSertests(tests.Modeltests):
                     "id": 4,
                     "ref_id": "1",
                     "type": "commented",
-                    "user": {"fullname": "PY C", "name": "pingou"},
+                    "user": {
+                        "fullname": "PY C",
+                        "name": "pingou",
+                        "url_path": "user/pingou",
+                    },
                 },
             ],
             "date": date,
@@ -464,14 +523,15 @@ class PagureFlaskApiUSertests(tests.Modeltests):
         will occur on XXXX-02-15 in UTC, but on XXXX-02-14 local.
         """
         tests.create_projects(self.session)
-        repo = pagure.lib.query._get_project(self.session, "test")
 
-        today = datetime.datetime.utcnow().date()
-        year = today.year
-        if today.year == 2 and today.date <= 15:
-            year = year - 1
-        elif today.year < 2:
-            year = year - 1
+        today = datetime.datetime.utcnow()
+        # stats/activty returns data for now()-1year time range, so alter
+        # year as needed to select 15th feb of current or previous year
+        if today < datetime.datetime(today.year, 2, 15, 3, 30):
+            year = today.year - 1
+        else:
+            year = today.year
+
         dateobj = datetime.datetime(year, 2, 15, 3, 30)
         utcdate = "%s-02-15" % year
         # the Unix timestamp for YYYY-02-15 12:00 UTC
@@ -483,7 +543,7 @@ class PagureFlaskApiUSertests(tests.Modeltests):
                 ).total_seconds()
             )
         )
-        localdate = "%s-02-14" % today.year
+        localdate = "%s-02-14" % year
         # the Unix timestamp for YYYY-02-15 18:00 America/New_York
         localts = str(
             int(
@@ -580,14 +640,15 @@ class PagureFlaskApiUSertests(tests.Modeltests):
         occur on XXXX-02-15 in UTC, but on XXXX-02-16 in local time.
         """
         tests.create_projects(self.session)
-        repo = pagure.lib.query._get_project(self.session, "test")
 
-        today = datetime.datetime.utcnow().date()
-        year = today.year
-        if today.year == 2 and today.date <= 15:
-            year = year - 1
-        elif today.year < 2:
-            year = year - 1
+        today = datetime.datetime.utcnow()
+        # stats/activty returns data for now()-1year time range, so alter
+        # year as needed to select 15th feb of current or previous year
+        if today < datetime.datetime(today.year, 2, 15, 3, 30):
+            year = today.year - 1
+        else:
+            year = today.year
+
         dateobj = datetime.datetime(year, 2, 15, 22, 30)
         utcdate = "%s-02-15" % year
         # the Unix timestamp for YYYY-02-15 12:00 UTC
@@ -1716,11 +1777,13 @@ class PagureFlaskApiUsertestissues(tests.Modeltests):
                         "project": {
                             "access_groups": {
                                 "admin": [],
+                                "collaborator": [],
                                 "commit": [],
                                 "ticket": [],
                             },
                             "access_users": {
                                 "admin": [],
+                                "collaborator": [],
                                 "commit": [],
                                 "owner": ["pingou"],
                                 "ticket": [],
@@ -1744,12 +1807,21 @@ class PagureFlaskApiUsertestissues(tests.Modeltests):
                             "priorities": {},
                             "tags": [],
                             "url_path": "test",
-                            "user": {"fullname": "PY C", "name": "pingou"},
+                            "user": {
+                                "fullname": "PY C",
+                                "name": "pingou",
+                                "url_path": "user/pingou",
+                            },
                         },
+                        "related_prs": [],
                         "status": "Open",
                         "tags": [],
                         "title": "Test issue",
-                        "user": {"fullname": "PY C", "name": "pingou"},
+                        "user": {
+                            "fullname": "PY C",
+                            "name": "pingou",
+                            "url_path": "user/pingou",
+                        },
                     }
                 ],
                 "pagination_issues_assigned": {
